kalabash-sievefilters
=====================

The sieve filters editor of Kalabash.

Installation
------------

Install this extension system-wide or inside a virtual environment by
running the following command::

  $ pip install kalabash-sievefilters
